# haxor-game-python

>  How good are you at haxoring?

Quickly ported haxor game from C++ to Python in 20 minutes.
 
C++ version: https://github.com/adavila0703/haxor-game

Inspired by: https://github.com/UnrealCourse2019/TripleX

Course: https://www.udemy.com/course/unrealcourse/
 
## Speed code video
[https://youtu.be/NhGe9e4Egfs](https://youtu.be/NhGe9e4Egfs)

